==> igniteui-react-charts-19.0.0.tgz: package/esm2015/lib/AnnotationLayerProxy.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, typeCast, delegateCombine, delegateRemove, markType } from "igniteui-react-core";
import { IAnnotationLayerProxy_$type } from "./IAnnotationLayerProxy";
import { CrosshairLayer } from "./CrosshairLayer";
import { ValueLayer } from "./ValueLayer";
import { CalloutLayer } from "./CalloutLayer";
import { FinalValueLayer } from "./FinalValueLayer";
import { TrendLineLayer } from "./TrendLineLayer";
import { DataToolTipLayer } from "./DataToolTipLayer";
import { DoubleCollection } from "igniteui-react-core";
/**
 * @hidden
 */
export let AnnotationLayerProxy = /*@__PURE__*/ (() => {
    class AnnotationLayerProxy extends Base {
        constructor() {
            super(...arguments);
            this._container = null;
        }
        get container() {
            return this._container;
        }
        set container(a) {
            this._container = a;
        }
        matchesType(a) {
            if (!a.eu) {
                return false;
            }
            return true;
        }
        createCrosshairLayer() {
            let a = new CrosshairLayer();
            let b = this.container.getExternal(a, null, null);
            return a;
        }
        createValueLayer() {
            let a = new ValueLayer();
            let b = this.container.getExternal(a, null, null);
            return a;
        }
        createCalloutLayer() {
            let a = new CalloutLayer();
            let b = this.container.getExternal(a, null, null);
            return a;
        }
        createFinalValueLayer() {
            let a = new FinalValueLayer();
            let b = this.container.getExternal(a, null, null);
            return a;
        }
        createTrendLineLayer() {
            let a = new TrendLineLayer();
            let b = this.container.getExternal(a, null, null);
            return a;
        }
        setCrosshairHorizontalLineVisibility(a, b) {
            a.ac1 = b;
        }
        setCrosshairVerticalLineVisibility(a, b) {
            a.ac2 = b;
        }
        setCrosshairHorizontalLineStroke(a, b) {
            a.acp = b;
        }
        setCrosshairVerticalLineStroke(a, b) {
            a.acq = b;
        }
        setCrosshairXAxisForeground(a, b) {
            a.act = b;
        }
        setCrosshairYAxisForeground(a, b) {
            a.acw = b;
        }
        setCrosshairXAxisBackground(a, b) {
            a.acr = b;
        }
        setCrosshairYAxisBackground(a, b) {
            a.acu = b;
        }
        setCrosshairYAxisPrecision(a, b) {
            a.aay = b;
        }
        setCrosshairXAxisPrecision(a, b) {
            a.aax = b;
        }
        setCrosshairOnAxesEnabled(a, b) {
            a.aag = b;
        }
        setCrosshairUseInterpolation(a, b) {
            a.aai = b;
        }
        setCrosshairThickness(a, b) {
            a.jq = b;
        }
        isCrosshairLayer(a) {
            return typeCast(CrosshairLayer.$, a) !== null;
        }
        setFinalValuePrecision(a, b) {
            a.aan = b;
        }
        setFinalValueBackground(a, b) {
            a.abh = b;
        }
        setFinalValueForeground(a, b) {
            a.abj = b;
        }
        setContentMemberPath(a, b) {
            a.adb = b;
        }
        setCalloutsAllowedPositions(a, b) {
            a.aan = b;
        }
        setLabelMemberPath(a, b) {
            a.adp = b;
        }
        setXMemberPath(a, b) {
            a.ad5 = b;
        }
        setYMemberPath(a, b) {
            a.ad8 = b;
        }
        setTargetSeries(a, b) {
            if (typeCast(CalloutLayer.$, a) !== null) {
                a.aas = b;
            }
            else {
                a.aal = b;
            }
        }
        setCollisionChannel(a, b) {
            a.ac8 = b;
        }
        setIsAutoCalloutBehaviorEnabled(a, b) {
            a.abj = b;
        }
        setGreedyCollisionMode(a, b) {
            a.aai = b ? 2 : 0;
        }
        setCollisionMode(a, b) {
            a.aai = b;
        }
        setUseItemColorForFill(a, b) {
            a.abq = b;
        }
        setUseItemColorForOutline(a, b) {
            a.abr = b;
        }
        setCalloutStrokeThickness(a, b) {
            a.acd = b;
        }
        setUseAutoContrastingLabelColors(a, b) {
            a.abo = b;
        }
        setCalloutBackground(a, b) {
            a.af1 = b;
        }
        setCalloutTextStyle(a, b) {
            if (b == null) {
                return;
            }
            let c = a;
            c.adv = b.fontString;
        }
        setAutoCalloutLabelPrecision(a, b) {
            a.acg = b;
        }
        setCalloutLightColor(a, b) {
            a.af4 = b;
        }
        setCalloutDarkColor(a, b) {
            a.af2 = b;
        }
        setCalloutOutline(a, b) {
            a.af5 = b;
        }
        setCalloutLeaderBrush(a, b) {
            a.af3 = b;
        }
        setCalloutTextColor(a, b) {
            a.af6 = b;
        }
        setShouldTruncateOnBoundaryCollisions(a, b) {
            a.abn = b;
        }
        setUseDedicatedLanes(a, b) {
            a.aag = b ? 2 : 0;
        }
        isCalloutLayer(a) {
            if (typeCast(CalloutLayer.$, a) !== null) {
                return true;
            }
            return false;
        }
        isDataToolTipLayer(a) {
            if (typeCast(DataToolTipLayer.$, a) !== null) {
                return true;
            }
            return false;
        }
        isFinalValueLayer(a) {
            if (typeCast(FinalValueLayer.$, a) !== null) {
                return true;
            }
            return false;
        }
        addCalloutStyleUpdating(a, b) {
            let c = a;
            c.calloutStyleUpdating = delegateCombine(c.calloutStyleUpdating, b);
        }
        removeCalloutStyleUpdating(a, b) {
            let c = a;
            c.calloutStyleUpdating = delegateRemove(c.calloutStyleUpdating, b);
        }
        addCalloutRenderStyleUpdating(a, b) {
            let c = a;
            c.calloutRenderStyleUpdating = delegateCombine(c.calloutRenderStyleUpdating, b);
        }
        removeCalloutRenderStyleUpdating(a, b) {
            let c = a;
            c.calloutRenderStyleUpdating = delegateRemove(c.calloutRenderStyleUpdating, b);
        }
        setCalloutStyleUpdatingEventEnabled(a, b) {
            a.abm = b;
        }
        setUseValueForAutoCalloutLabels(a, b) {
            a.abt = b;
        }
        setCalloutRenderStyleUpdatingEventEnabled(a, b) {
            a.abl = b;
        }
        updateDataToolTipPropertyByName(a, b, c) {
            a.afx(b, c);
        }
        getIsAutoCalloutBehaviorEnabled(a) {
            return a.abj;
        }
        setValueMode(a, b) {
            a.aan = b;
        }
        setUseLegend(a, b) {
            a.xq = b;
        }
        setTitle(a, b) {
            a.title = b;
        }
        setLegendItemBadgeShape(a, b) {
            a.legendItemBadgeShape = b;
        }
        setValueAxisAnnotationEnabled(a, b) {
            a.aar = b;
        }
        getValueMode(a) {
            return a.aan;
        }
        isValueLayer(a) {
            return typeCast(ValueLayer.$, a) !== null;
        }
        setBrush(a, b) {
            a.vk = b;
        }
        setDashArray(a, b) {
            let c = new DoubleCollection();
            for (let d = 0; d < b.length; d++) {
                c.add(b[d]);
            }
            a.v7 = c;
        }
        isTrendLineLayer(a) {
            return typeCast(TrendLineLayer.$, a) !== null;
        }
        setTrendLineTarget(a, b) {
            a.aab = b;
        }
        setTrendLineType(a, b) {
            a.aad = b;
        }
        setTrendLineBrush(a, b) {
            a.vk = b;
        }
        setTrendLineDashArray(a, b) {
            a.v7 = b;
        }
        setTrendLineDashCap(a, b) {
            a.v8 = b;
        }
        setTrendLineThickness(a, b) {
            a.jq = b;
        }
        getTrendLineType(a) {
            return a.aad;
        }
        setAppearanceMode(a, b) {
            switch (b) {
                case "BrightnessShift":
                    a.w6 = 1;
                    break;
                case "SaturationShift":
                    a.w6 = 2;
                    break;
                case "OpacityShift":
                    a.w6 = 4;
                    break;
                case "DashPattern":
                    a.w6 = 3;
                    break;
                case "Auto":
                    a.w6 = 0;
                    break;
            }
        }
    }
    AnnotationLayerProxy.$t = /*@__PURE__*/ markType(AnnotationLayerProxy, 'AnnotationLayerProxy', Base.$, [IAnnotationLayerProxy_$type]);
    return AnnotationLayerProxy;
})();

==> igniteui-react-charts-19.0.1.tgz: package/esm2015/lib/AnnotationLayerProxy.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, typeCast, delegateCombine, delegateRemove, markType } from "igniteui-react-core";
import { IAnnotationLayerProxy_$type } from "./IAnnotationLayerProxy";
import { CrosshairLayer } from "./CrosshairLayer";
import { ValueLayer } from "./ValueLayer";
import { CalloutLayer } from "./CalloutLayer";
import { FinalValueLayer } from "./FinalValueLayer";
import { TrendLineLayer } from "./TrendLineLayer";
import { DataToolTipLayer } from "./DataToolTipLayer";
import { DoubleCollection } from "igniteui-react-core";
/**
 * @hidden
 */
export let AnnotationLayerProxy = /*@__PURE__*/ (() => {
    class AnnotationLayerProxy extends Base {
        constructor() {
            super(...arguments);
            this._container = null;
        }
        get container() {
            return this._container;
        }
        set container(a) {
            this._container = a;
        }
        matchesType(a) {
            if (!a.eu) {
                return false;
            }
            return true;
        }
        createCrosshairLayer() {
            let a = new CrosshairLayer();
            let b = this.container.getExternal(a, null, null);
            return a;
        }
        createValueLayer() {
            let a = new ValueLayer();
            let b = this.container.getExternal(a, null, null);
            return a;
        }
        createCalloutLayer() {
            let a = new CalloutLayer();
            let b = this.container.getExternal(a, null, null);
            return a;
        }
        createFinalValueLayer() {
            let a = new FinalValueLayer();
            let b = this.container.getExternal(a, null, null);
            return a;
        }
        createTrendLineLayer() {
            let a = new TrendLineLayer();
            let b = this.container.getExternal(a, null, null);
            return a;
        }
        setCrosshairHorizontalLineVisibility(a, b) {
            a.ac7 = b;
        }
        setCrosshairVerticalLineVisibility(a, b) {
            a.ac8 = b;
        }
        setCrosshairHorizontalLineStroke(a, b) {
            a.acv = b;
        }
        setCrosshairVerticalLineStroke(a, b) {
            a.acw = b;
        }
        setCrosshairXAxisForeground(a, b) {
            a.acz = b;
        }
        setCrosshairYAxisForeground(a, b) {
            a.ac2 = b;
        }
        setCrosshairXAxisBackground(a, b) {
            a.acx = b;
        }
        setCrosshairYAxisBackground(a, b) {
            a.ac0 = b;
        }
        setCrosshairYAxisPrecision(a, b) {
            a.aa0 = b;
        }
        setCrosshairXAxisPrecision(a, b) {
            a.aaz = b;
        }
        setCrosshairOnAxesEnabled(a, b) {
            a.aag = b;
        }
        setCrosshairSkipZeroValueFragments(a, b) {
            a.aai = b;
        }
        setCrosshairSkipInvalidData(a, b) {
            a.aah = b;
        }
        setCrosshairUseInterpolation(a, b) {
            a.aak = b;
        }
        setCrosshairThickness(a, b) {
            a.jq = b;
        }
        isCrosshairLayer(a) {
            return typeCast(CrosshairLayer.$, a) !== null;
        }
        setFinalValuePrecision(a, b) {
            a.aan = b;
        }
        setFinalValueBackground(a, b) {
            a.abh = b;
        }
        setFinalValueForeground(a, b) {
            a.abj = b;
        }
        setContentMemberPath(a, b) {
            a.adq = b;
        }
        setCalloutsAllowedPositions(a, b) {
            a.aan = b;
        }
        setLabelMemberPath(a, b) {
            a.ad4 = b;
        }
        setXMemberPath(a, b) {
            a.aek = b;
        }
        setYMemberPath(a, b) {
            a.aen = b;
        }
        setTargetSeries(a, b) {
            if (typeCast(CalloutLayer.$, a) !== null) {
                a.aas = b;
            }
            else {
                a.aal = b;
            }
        }
        setCollisionChannel(a, b) {
            a.adn = b;
        }
        setIsAutoCalloutBehaviorEnabled(a, b) {
            a.abq = b;
        }
        setGreedyCollisionMode(a, b) {
            a.aai = b ? 2 : 0;
        }
        setCollisionMode(a, b) {
            a.aai = b;
        }
        setUseItemColorForFill(a, b) {
            a.abx = b;
        }
        setUseItemColorForOutline(a, b) {
            a.aby = b;
        }
        setCalloutStrokeThickness(a, b) {
            a.aco = b;
        }
        setUseAutoContrastingLabelColors(a, b) {
            a.abv = b;
        }
        setCalloutBackground(a, b) {
            a.agk = b;
        }
        setCalloutTextStyle(a, b) {
            if (b == null) {
                return;
            }
            let c = a;
            c.aea = b.fontString;
        }
        setAutoCalloutLabelPrecision(a, b) {
            a.acs = b;
        }
        setCalloutLightColor(a, b) {
            a.agn = b;
        }
        setCalloutDarkColor(a, b) {
            a.agl = b;
        }
        setCalloutOutline(a, b) {
            a.ago = b;
        }
        setCalloutLeaderBrush(a, b) {
            a.agm = b;
        }
        setCalloutTextColor(a, b) {
            a.agp = b;
        }
        setShouldTruncateOnBoundaryCollisions(a, b) {
            a.abu = b;
        }
        setUseDedicatedLanes(a, b) {
            a.aag = b ? 2 : 0;
        }
        isCalloutLayer(a) {
            if (typeCast(CalloutLayer.$, a) !== null) {
                return true;
            }
            return false;
        }
        isDataToolTipLayer(a) {
            if (typeCast(DataToolTipLayer.$, a) !== null) {
                return true;
            }
            return false;
        }
        isFinalValueLayer(a) {
            if (typeCast(FinalValueLayer.$, a) !== null) {
                return true;
            }
            return false;
        }
        addCalloutStyleUpdating(a, b) {
            let c = a;
            c.calloutStyleUpdating = delegateCombine(c.calloutStyleUpdating, b);
        }
        removeCalloutStyleUpdating(a, b) {
            let c = a;
            c.calloutStyleUpdating = delegateRemove(c.calloutStyleUpdating, b);
        }
        addCalloutRenderStyleUpdating(a, b) {
            let c = a;
            c.calloutRenderStyleUpdating = delegateCombine(c.calloutRenderStyleUpdating, b);
        }
        removeCalloutRenderStyleUpdating(a, b) {
            let c = a;
            c.calloutRenderStyleUpdating = delegateRemove(c.calloutRenderStyleUpdating, b);
        }
        setCalloutStyleUpdatingEventEnabled(a, b) {
            a.abt = b;
        }
        setUseValueForAutoCalloutLabels(a, b) {
            a.ab0 = b;
        }
        setCalloutRenderStyleUpdatingEventEnabled(a, b) {
            a.abs = b;
        }
        updateDataToolTipPropertyByName(a, b, c) {
            a.afx(b, c);
        }
        getIsAutoCalloutBehaviorEnabled(a) {
            return a.abq;
        }
        setValueMode(a, b) {
            a.aan = b;
        }
        setUseLegend(a, b) {
            a.xq = b;
        }
        setTitle(a, b) {
            a.title = b;
        }
        setLegendItemBadgeShape(a, b) {
            a.legendItemBadgeShape = b;
        }
        setValueAxisAnnotationEnabled(a, b) {
            a.aar = b;
        }
        getValueMode(a) {
            return a.aan;
        }
        isValueLayer(a) {
            return typeCast(ValueLayer.$, a) !== null;
        }
        setBrush(a, b) {
            a.vk = b;
        }
        setDashArray(a, b) {
            let c = new DoubleCollection();
            for (let d = 0; d < b.length; d++) {
                c.add(b[d]);
            }
            a.v7 = c;
        }
        isTrendLineLayer(a) {
            return typeCast(TrendLineLayer.$, a) !== null;
        }
        setTrendLineTarget(a, b) {
            a.aab = b;
        }
        setTrendLineType(a, b) {
            a.aad = b;
        }
        setTrendLineBrush(a, b) {
            a.vk = b;
        }
        setTrendLineDashArray(a, b) {
            a.v7 = b;
        }
        setTrendLineDashCap(a, b) {
            a.v8 = b;
        }
        setTrendLineThickness(a, b) {
            a.jq = b;
        }
        getTrendLineType(a) {
            return a.aad;
        }
        setAppearanceMode(a, b) {
            switch (b) {
                case "BrightnessShift":
                    a.w6 = 1;
                    break;
                case "SaturationShift":
                    a.w6 = 2;
                    break;
                case "OpacityShift":
                    a.w6 = 4;
                    break;
                case "DashPattern":
                    a.w6 = 3;
                    break;
                case "Auto":
                    a.w6 = 0;
                    break;
            }
        }
    }
    AnnotationLayerProxy.$t = /*@__PURE__*/ markType(AnnotationLayerProxy, 'AnnotationLayerProxy', Base.$, [IAnnotationLayerProxy_$type]);
    return AnnotationLayerProxy;
})();
